@@ -302,10 +302,9 @@ class NumerousSimulationJob(NumerousBaseJob):
 
             while True:
 
-                completed = 0
                 if t_stop > 0:
                     self._completed = (1 - (t_stop - self._t) / (t_stop - self.app.start_time)) * 100
-                    self.app.client.set_scenario_progress("running", ScenarioStatus.RUNNING, completed)
+                    self.app.client.set_scenario_progress("running", ScenarioStatus.RUNNING, self._completed)
 
                 i+=1
                 if self.app.backup.is_set():
